@@ -23,7 +23,7 @@ Data manipulation
 
 .. attribute:: VALUE_MERGERS
 
-    Default series of mergers:
+    Default sequence of mergers:
 
     * :class:`TypeMerger`
     * :class:`DictMerger`
@@ -48,14 +48,14 @@ class ValueMerger(object):
 
         Subclasses must overload this method.
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: nocover
 
     def process(self):
         """ Returns a merged version or `self.spec` and `self.value`.
 
         Subclasses must overload this method.
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: nocover
 
 
 class TypeMerger(ValueMerger):
@@ -162,7 +162,7 @@ def merge_value(spec, value, mergers):
     """ Returns a merged value based on given spec and data, using given
     sequence of mergers.
 
-    The mergers are polled expected to be subclasses of :class:`ValueMerger`.
+    The mergers are expected to be subclasses of :class:`ValueMerger`.
     They are polled one by one; the first one that agrees to process given
     value is used to produce the result.
 
@@ -181,7 +181,7 @@ def merge_value(spec, value, mergers):
     return value
 
 
-def merged(spec, data, value_processor=None, mergers=VALUE_MERGERS):
+def merged(spec, data, mergers=VALUE_MERGERS):
     """ Returns a dictionary based on `spec` + `data`.
 
     Does not validate values. If `data` overrides a default value, it is
@@ -198,10 +198,8 @@ def merged(spec, data, value_processor=None, mergers=VALUE_MERGERS):
         `dict`. A document structure specification.
     :param data:
         `dict`. Overrides some or all default values from the spec.
-    :param value_processor:
-        function, must take one argument and return the modified value.
     :param mergers:
-        `tuple`. An ordered series of :class:`ValueMerger` subclasses.
+        `sequence`. An ordered series of :class:`ValueMerger` subclasses.
         Default is :attr:`VALUE_MERGERS`. The mergers are passed to
         :func:`merge_value`.
     """
@@ -218,9 +216,6 @@ def merged(spec, data, value_processor=None, mergers=VALUE_MERGERS):
             # them as they aren't in the spec
             value = data[key]
 
-        if value_processor:
-            value = value_processor(value)
-
         result[key] = value
 
     return result
